==> libdatetime-locale-perl_1.16.orig.tar.gz: DateTime-Locale-1.16/share/bm.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "MM-dd, E",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "bm",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "nt\N{U+025b}",
    "tar",
    "ara",
    "ala",
    "jum",
    "sib",
    "kar"
  ],
  day_format_narrow => [
    "N",
    "T",
    "A",
    "A",
    "J",
    "S",
    "K"
  ],
  day_format_wide => [
    "nt\N{U+025b}n\N{U+025b}",
    "tarata",
    "araba",
    "alamisa",
    "juma",
    "sibiri",
    "kari"
  ],
  day_stand_alone_abbreviated => [
    "nt\N{U+025b}",
    "tar",
    "ara",
    "ala",
    "jum",
    "sib",
    "kar"
  ],
  day_stand_alone_narrow => [
    "N",
    "T",
    "A",
    "A",
    "J",
    "S",
    "K"
  ],
  day_stand_alone_wide => [
    "nt\N{U+025b}n\N{U+025b}",
    "tarata",
    "araba",
    "alamisa",
    "juma",
    "sibiri",
    "kari"
  ],
  era_abbreviated => [
    "J.-C. \N{U+0272}\N{U+025b}",
    "ni J.-C."
  ],
  era_narrow => [
    "J.-C. \N{U+0272}\N{U+025b}",
    "ni J.-C."
  ],
  era_wide => [
    "jezu krisiti \N{U+0272}\N{U+025b}",
    "jezu krisiti mink\N{U+025b}"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Bambara",
  month_format_abbreviated => [
    "zan",
    "feb",
    "mar",
    "awi",
    "m\N{U+025b}",
    "zuw",
    "zul",
    "uti",
    "s\N{U+025b}t",
    "\N{U+0254}ku",
    "now",
    "des"
  ],
  month_format_narrow => [
    "Z",
    "F",
    "M",
    "A",
    "M",
    "Z",
    "Z",
    "U",
    "S",
    "\N{U+0186}",
    "N",
    "D"
  ],
  month_format_wide => [
    "zanwuye",
    "feburuye",
    "marisi",
    "awirili",
    "m\N{U+025b}",
    "zuw\N{U+025b}n",
    "zuluye",
    "uti",
    "s\N{U+025b}tanburu",
    "\N{U+0254}kut\N{U+0254}buru",
    "nowanburu",
    "desanburu"
  ],
  month_stand_alone_abbreviated => [
    "zan",
    "feb",
    "mar",
    "awi",
    "m\N{U+025b}",
    "zuw",
    "zul",
    "uti",
    "s\N{U+025b}t",
    "\N{U+0254}ku",
    "now",
    "des"
  ],
  month_stand_alone_narrow => [
    "Z",
    "F",
    "M",
    "A",
    "M",
    "Z",
    "Z",
    "U",
    "S",
    "\N{U+0186}",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "zanwuye",
    "feburuye",
    "marisi",
    "awirili",
    "m\N{U+025b}",
    "zuw\N{U+025b}n",
    "zuluye",
    "uti",
    "s\N{U+025b}tanburu",
    "\N{U+0254}kut\N{U+0254}buru",
    "nowanburu",
    "desanburu"
  ],
  name => "Bambara",
  native_language => "bamanakan",
  native_name => "bamanakan",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "KS1",
    "KS2",
    "KS3",
    "KS4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "kalo saba f\N{U+0254}l\N{U+0254}",
    "kalo saba filanan",
    "kalo saba sabanan",
    "kalo saba naaninan"
  ],
  quarter_stand_alone_abbreviated => [
    "KS1",
    "KS2",
    "KS3",
    "KS4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "kalo saba f\N{U+0254}l\N{U+0254}",
    "kalo saba filanan",
    "kalo saba sabanan",
    "kalo saba naaninan"
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/bm.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "MM-dd, E",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "bm",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "nt\N{U+025b}",
    "tar",
    "ara",
    "ala",
    "jum",
    "sib",
    "kar",
  ],
  day_format_narrow => [
    "N",
    "T",
    "A",
    "A",
    "J",
    "S",
    "K",
  ],
  day_format_wide => [
    "nt\N{U+025b}n\N{U+025b}",
    "tarata",
    "araba",
    "alamisa",
    "juma",
    "sibiri",
    "kari",
  ],
  day_stand_alone_abbreviated => [
    "nt\N{U+025b}",
    "tar",
    "ara",
    "ala",
    "jum",
    "sib",
    "kar",
  ],
  day_stand_alone_narrow => [
    "N",
    "T",
    "A",
    "A",
    "J",
    "S",
    "K",
  ],
  day_stand_alone_wide => [
    "nt\N{U+025b}n\N{U+025b}",
    "tarata",
    "araba",
    "alamisa",
    "juma",
    "sibiri",
    "kari",
  ],
  era_abbreviated => [
    "J.-C. \N{U+0272}\N{U+025b}",
    "ni J.-C.",
  ],
  era_narrow => [
    "J.-C. \N{U+0272}\N{U+025b}",
    "ni J.-C.",
  ],
  era_wide => [
    "jezu krisiti \N{U+0272}\N{U+025b}",
    "jezu krisiti mink\N{U+025b}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Bambara",
  month_format_abbreviated => [
    "zan",
    "feb",
    "mar",
    "awi",
    "m\N{U+025b}",
    "zuw",
    "zul",
    "uti",
    "s\N{U+025b}t",
    "\N{U+0254}ku",
    "now",
    "des",
  ],
  month_format_narrow => [
    "Z",
    "F",
    "M",
    "A",
    "M",
    "Z",
    "Z",
    "U",
    "S",
    "\N{U+0186}",
    "N",
    "D",
  ],
  month_format_wide => [
    "zanwuye",
    "feburuye",
    "marisi",
    "awirili",
    "m\N{U+025b}",
    "zuw\N{U+025b}n",
    "zuluye",
    "uti",
    "s\N{U+025b}tanburu",
    "\N{U+0254}kut\N{U+0254}buru",
    "nowanburu",
    "desanburu",
  ],
  month_stand_alone_abbreviated => [
    "zan",
    "feb",
    "mar",
    "awi",
    "m\N{U+025b}",
    "zuw",
    "zul",
    "uti",
    "s\N{U+025b}t",
    "\N{U+0254}ku",
    "now",
    "des",
  ],
  month_stand_alone_narrow => [
    "Z",
    "F",
    "M",
    "A",
    "M",
    "Z",
    "Z",
    "U",
    "S",
    "\N{U+0186}",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "zanwuye",
    "feburuye",
    "marisi",
    "awirili",
    "m\N{U+025b}",
    "zuw\N{U+025b}n",
    "zuluye",
    "uti",
    "s\N{U+025b}tanburu",
    "\N{U+0254}kut\N{U+0254}buru",
    "nowanburu",
    "desanburu",
  ],
  name => "Bambara",
  native_language => "bamanakan",
  native_name => "bamanakan",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "KS1",
    "KS2",
    "KS3",
    "KS4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "kalo saba f\N{U+0254}l\N{U+0254}",
    "kalo saba filanan",
    "kalo saba sabanan",
    "kalo saba naaninan",
  ],
  quarter_stand_alone_abbreviated => [
    "KS1",
    "KS2",
    "KS3",
    "KS4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "kalo saba f\N{U+0254}l\N{U+0254}",
    "kalo saba filanan",
    "kalo saba sabanan",
    "kalo saba naaninan",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
